@@ -1,12 +1,11 @@
 package Task::BeLike::SHARYANTO::Devel;
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 1;
 # ABSTRACT: Install modules currently used in SHARYANTO's developing environment
 
 
-
 __END__
 =pod
 
@@ -16,7 +15,7 @@ Task::BeLike::SHARYANTO::Devel - Install modules currently used in SHARYANTO's d
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 DESCRIPTION
 
@@ -27,11 +26,9 @@ Not included are modules:
 
 =item * already in 5.10 core;
 
-=item * used in applications (see L<Task::BeLike::SHARYANTO::Apps>);
+=item * written by me (see L<Task::BeLike::SHARYANTO::Authored>);
 
-=item * required by my very specific applications;
-
-=item * required by my old/obsolete applications;
+=item * used in my applications (see L<Task::BeLike::SHARYANTO::Apps>);
 
 =back
 
@@ -39,6 +36,16 @@ The purpose of this distribution is to make it easy to setup my developing
 environment. Thus, this distribution is probably only useful to me or people who
 want to imitate my developing environment.
 
+Todo/futures:
+
+=over 4
+
+=item * carton
+
+=item * Pinto
+
+=back
+
 =head1 TASK CONTENTS
 
 =head2 Included modules
@@ -51,16 +58,20 @@ want to imitate my developing environment.
 
 =head3 L<App::perlzonji>
 
+=head3 L<Carp::Always>
+
+=head3 L<Carp::Always::Color>
+
 =head3 L<Class::Autouse>
 
 =head3 L<CPAN::Mini>
 
-=head3 L<Devel::EndStats>
+=head3 L<Data::Dump>
+
+=head3 L<Devel::NYTProf>
 
 =head3 L<Dist::Zilla>
 
-=head3 L<Dist::Zilla::PluginBundle::SHARYANTO>
-
 =head3 L<Module::CoreList>
 
 =head1 AUTHOR
